@@ -28,6 +28,8 @@
 #include <QTimer>
 #include <QLayout>
 
+#include <KWindowSystem>
+
 #include <Plasma/Corona>
 #include <Plasma/Dialog>
 #include <Plasma/WindowEffects>
@@ -201,6 +203,14 @@ void DialogProxy::setVisible(const bool visible)
         const QSize s = m_dialog->size();
         m_dialog->resize(0,0);
         m_dialog->resize(s);
+
+        const QRect workArea(KWindowSystem::workArea());
+        if (!workArea.contains(m_dialog->geometry())) {
+            m_dialog->move(qBound(workArea.left(), m_dialog->x(), workArea.right() - m_dialog->width()),
+                             qBound(workArea.top(), m_dialog->y(), workArea.bottom() - m_dialog->height())
+            );
+        }
+
         m_dialog->setVisible(visible);
         if (visible) {
             m_dialog->raise();
@@ -409,6 +419,11 @@ bool DialogProxy::eventFilter(QObject *watched, QEvent *event)
         }
     } else if (watched == m_dialog && event->type() == QEvent::Show) {
         Plasma::WindowEffects::slideWindow(m_dialog, m_location);
+        if (m_dialog->testAttribute(Qt::WA_X11NetWmWindowTypeDock)) {
+            KWindowSystem::setOnAllDesktops(m_dialog->winId(), true);
+        } else {
+            KWindowSystem::setOnAllDesktops(m_dialog->winId(), false);
+        }
         emit visibleChanged();
     } else if (watched == m_dialog && event->type() == QEvent::Hide) {
         Plasma::WindowEffects::slideWindow(m_dialog, m_location);
@@ -426,6 +441,12 @@ bool DialogProxy::eventFilter(QObject *watched, QEvent *event)
 void DialogProxy::setAttribute(int attribute, bool on)
 {
     m_dialog->setAttribute((Qt::WidgetAttribute)attribute, on);
+
+    if (attribute == Qt::WA_X11NetWmWindowTypeDock) {
+        KWindowSystem::setOnAllDesktops(m_dialog->winId(), true);
+    } else {
+        KWindowSystem::setOnAllDesktops(m_dialog->winId(), false);
+    }
 }
 
 #include "dialog.moc"
