@@ -64,6 +64,7 @@ K_EXPORT_PLASMA_APPLETSCRIPTENGINE(declarativeappletscript, DeclarativeAppletScr
 
 QScriptValue constructIconClass(QScriptEngine *engine);
 QScriptValue constructKUrlClass(QScriptEngine *engine);
+QScriptValue constructQPointClass(QScriptEngine *engine);
 void registerSimpleAppletMetaTypes(QScriptEngine *engine);
 DeclarativeAppletScript::DeclarativeAppletScript(QObject *parent, const QVariantList &args)
     : AbstractJsAppletScript(parent, args),
@@ -150,7 +151,7 @@ void DeclarativeAppletScript::qmlCreationFinished()
     if (pa) {
         QDeclarativeComponent *iconComponent = m_declarativeWidget->rootObject()->property("compactRepresentation").value<QDeclarativeComponent *>();
         if (iconComponent) {
-            QDeclarativeItem *declarativeIcon = qobject_cast<QDeclarativeItem *>(iconComponent->create(m_declarativeWidget->engine()->rootContext()));
+            QDeclarativeItem *declarativeIcon = qobject_cast<QDeclarativeItem *>(iconComponent->create(iconComponent->creationContext()));
             if (declarativeIcon) {
                 pa->setPopupIcon(QIcon());
                 QGraphicsLinearLayout *lay = new QGraphicsLinearLayout(a);
@@ -388,9 +389,8 @@ void DeclarativeAppletScript::executeAction(const QString &name)
         return;
     }
 
-    const QString func("action_" + name);
-    if (!m_env->callEventListeners(func)) {
-        callPlasmoidFunction(func, QScriptValueList(), m_env);
+    if (m_declarativeWidget->rootObject()) {
+         QMetaObject::invokeMethod(m_declarativeWidget->rootObject(), QString("action_" + name).toLatin1(), Qt::DirectConnection);
     }
 }
 
@@ -450,6 +450,7 @@ void DeclarativeAppletScript::setupObjects()
     //TODO: move to libkdeclarative?
     ByteArrayClass *baClass = new ByteArrayClass(m_engine);
     global.setProperty("ByteArray", baClass->constructor());
+    global.setProperty("QPoint", constructQPointClass(m_engine));
 
     // Add stuff from Plasma
     global.setProperty("Svg", m_engine->newFunction(DeclarativeAppletScript::newPlasmaSvg));
